/*  File:    load.pl
    Purpose: Load all boot files
    Author:  Jan Wielemaker
    Date:    Jul 29 1990
*/

:-	[ syspred
	, messages
	, toplevel
	, listing
	, edit
	, sort
	, bags
	, apply
	, list
	, writef
	, history
	, profile
	, dwim
	, foreign
	, parms
	, autoload
	, qlf
	, user:topvars
	].
